@@ -24,12 +24,13 @@ class DirectingOtherAnimalsVisualizer(object):
 
     Notes
     -----
+    Requires the pose-estimation data for the ``left ear``, ``right ear`` and ``nose`` of
+    each individual animals. `YouTube example of expected output <https://youtu.be/4WXs3sKu41I>`__.
 
     Examples
     -----
     >>> directing_visualizer = DirectingOtherAnimalsVisualizer(config_path='MyProjectConfig')
     >>> directing_visualizer.visualize_results()
-
     """
 
     def __init__(self,
