@@ -1,17 +1,18 @@
 __author__ = "Simon Nilsson", "JJ Choong"
 
 from simba.read_config_unit_tests import (check_int,
-                                             check_str,
-                                             check_float,
-                                             read_config_entry,
-                                             read_config_file)
+                                          check_str,
+                                          check_float,
+                                          read_config_entry,
+                                          read_config_file)
 import os, glob
 import pandas as pd
 from datetime import datetime
 from simba.features_scripts.unit_tests import read_video_info_csv, read_video_info
 from simba.drop_bp_cords import get_fn_ext
 from simba.rw_dfs import read_df
-from simba.misc_tools import detect_bouts
+from simba.misc_tools import (detect_bouts,
+                              SimbaTimer)
 import itertools
 import seaborn as sns
 
@@ -27,7 +28,7 @@ class FSTTCPerformer(object):
     time_window: int
         Integer representing the time window in seconds
     behavior_lst: list
-        List of behaviors to calculate FSTTC between.
+        Behaviors to calculate FSTTC between.
     create_graphs: bool
         If True, created violin plots representing each FSTTC
 
@@ -59,6 +60,8 @@ class FSTTCPerformer(object):
                  behavior_lst: list,
                  create_graphs: bool):
 
+        self.timer = SimbaTimer()
+        self.timer.start_timer()
         self.time_delta = int(time_window)
         self.behavior_lst = behavior_lst
         self.graph_status = create_graphs
@@ -199,12 +202,13 @@ class FSTTCPerformer(object):
             self.out_df = pd.concat([self.out_df,video_df], axis=0)
         file_save_path = os.path.join(self.logs_folder, 'FSTTC_{}.csv'.format(str(self.datetime)))
         self.out_df.to_csv(file_save_path)
-        print('SIMBA COMPLETE: FSTTC data saved at {}'.format(file_save_path))
+        self.timer.stop_timer()
+        print('SIMBA COMPLETE: FSTTC data saved at {} (elapsed time: {}s)'.format(file_save_path, self.timer.elapsed_time_str))
 
     def plot_FSTTC(self):
         """
-        Method to visualize forward spike-time tiling coefficients (FSTTC) as png violin plots. Results are stored on disk
-        within the `project_folder/logs` directory.
+        Method to visualize forward spike-time tiling coefficients (FSTTC) as png violin plots. Results are stored on
+        disk within the `project_folder/logs` directory.
 
         Returns
         -------
