@@ -6,6 +6,7 @@ from simba.read_config_unit_tests import (read_config_file,
                                              check_str,
                                              check_float,
                                              read_config_entry)
+from simba.misc_tools import SimbaTimer
 
 import os, glob
 from datetime import datetime
@@ -27,7 +28,7 @@ class KleinbergCalculator(object):
     config_path: str
         path to SimBA project config file in Configparser format
     classifier_names: list
-        List of classifier names to smooth.
+        Classifier names to apply Kleinberg smoothing to.
     sigma: float
         Burst detection sigma value. Higher sigma values and fewer, longer, behavioural bursts will be recognised.
     gamma: float
@@ -65,6 +66,8 @@ class KleinbergCalculator(object):
                  hierarchy=1,
                  hierarchical_search=False):
 
+        self.timer = SimbaTimer()
+        self.timer.start_timer()
         self.config = read_config_file(config_path)
         self.project_path = read_config_entry(self.config, 'General settings', 'project_path', data_type='folder_path')
         self.in_path = os.path.join(self.project_path, 'csv', 'machine_results')
@@ -157,13 +160,14 @@ class KleinbergCalculator(object):
                     video_out_df.loc[hierarchy_idx, clf] = 1
             save_df(video_out_df, self.file_type, file_path)
 
+        self.timer.stop_timer()
         if len(detailed_df_lst) > 0:
             detailed_df = pd.concat(detailed_df_lst, axis=0)
             detailed_save_path = os.path.join(self.logs_folder, 'Kleinberg_detailed_log_{}.csv'.format(str(self.datetime)))
             detailed_df.to_csv(detailed_save_path)
-            print('SIMBA COMPLETE: Kleinberg analysis complete. See {} for details of detected bouts of all classifiers in all hierarchies'.format(detailed_save_path))
+            print('SIMBA COMPLETE: Kleinberg analysis complete. See {} for details of detected bouts of all classifiers in all hierarchies (elapsed time: {}s)'.format(detailed_save_path, self.timer.elapsed_time_str))
         else:
-            print('SIMBA WARNING: All behavior bouts removed following kleinberg smoothing.')
+            print('SIMBA WARNING: All behavior bouts removed following kleinberg smoothing (elapsed time: {}s).'.format(self.timer.elapsed_time_str))
 
 
 # test = KleinbergCalculator(config_path='/Users/simon/Desktop/troubleshooting/train_model_project_1/project_folder/project_config.ini',
