@@ -10,9 +10,13 @@ import numpy as np
 from shapely.geometry import Point, Polygon
 from simba.drop_bp_cords import getBpHeaders, get_fn_ext
 from simba.rw_dfs import *
-from simba.features_scripts.unit_tests import read_video_info_csv, read_video_info
-from simba.misc_tools import check_multi_animal_status
-from simba.read_config_unit_tests import read_config_entry, check_that_column_exist, read_config_file
+from simba.features_scripts.unit_tests import (read_video_info_csv,
+                                               read_video_info)
+from simba.misc_tools import (check_multi_animal_status,
+                              SimbaTimer)
+from simba.read_config_unit_tests import (read_config_entry,
+                                          check_that_column_exist,
+                                          read_config_file)
 
 class ROIAnalyzer(object):
     """
@@ -66,10 +70,9 @@ class ROIAnalyzer(object):
             self.files_found = glob.glob(self.input_folder + '/*.' + self.file_type)
             if len(self.files_found) == 0:
                 print('SIMBA ERROR: No data files found in {}'.format(self.input_folder))
-                raise ValueError('SIMBA ERROR: No data files found in {}'.format(self.input_folder))
+                raise ValueError('SIMBA ERROR: No data files found.')
 
         self.multiAnimalStatus, self.multiAnimalIDList = check_multi_animal_status(config, self.no_animals)
-
         self.bp_dict = defaultdict(list)
         self.bp_columns = []
         for cnt, animal in enumerate(self.multiAnimalIDList):
@@ -80,6 +83,8 @@ class ROIAnalyzer(object):
             for c in ['_x', '_y', '_p']:
                 self.bp_dict[animal].append(bp_name + c)
                 self.bp_columns.append(bp_name + c)
+        self.timer = SimbaTimer()
+        self.timer.start_timer()
 
     def read_roi_dfs(self):
 
@@ -272,8 +277,6 @@ class ROIAnalyzer(object):
         None
         """
 
-
-
         for data_name, data in zip(['Detailed_ROI_data', 'ROI_time_data', 'ROI_entry_data'], [self.entry_exit_df_lst, self.time_df_lst, self.entry_df_lst]):
             save_df = pd.concat(data, axis=0).reset_index(drop=True)
             save_path = os.path.join(self.logs_path, data_name + '_' + self.timestamp + '.csv')
@@ -284,8 +287,9 @@ class ROIAnalyzer(object):
             save_df = pd.concat(self.dist_lst, axis=0).reset_index(drop=True)
             save_path = os.path.join(self.logs_path, 'ROI_movement_data_' + self.timestamp + '.csv')
             save_df.to_csv(save_path)
-        print('ROI movement data saved in the "project_folder/logs/" directory')
-        print('SIMBA COMPLETE: ROI analysis complete.')
+            print('ROI movement data saved in the "project_folder/logs/" directory')
+        self.timer.stop_timer()
+        print('SIMBA COMPLETE: ROI analysis complete (elapsed time: {}s)'.format(self.timer.elapsed_time_str))
 
 # test = ROIAnalyzer(ini_path = r"/Users/simon/Desktop/troubleshooting/train_model_project/project_folder/project_config.ini",
 #                    data_path = "outlier_corrected_movement_location", calculate_distances=True)
