@@ -1,14 +1,24 @@
 __author__ = "Simon Nilsson", "JJ Choong"
 
-from simba.read_config_unit_tests import (check_int, check_str, check_float, read_config_entry, read_config_file)
+from simba.read_config_unit_tests import (check_int,
+                                          check_str,
+                                          check_float,
+                                          read_config_entry,
+                                          read_config_file)
 from simba.ROI_directing_analyzer import DirectingROIAnalyzer
 from datetime import datetime
 import numpy as np
 import os, glob
 from simba.rw_dfs import read_df, save_df
-from simba.features_scripts.unit_tests import read_video_info_csv, read_video_info
-from simba.misc_tools import check_multi_animal_status, check_directionality_viable
-from simba.drop_bp_cords import getBpNames, createColorListofList, create_body_part_dictionary, get_fn_ext
+from simba.features_scripts.unit_tests import (read_video_info_csv,
+                                               read_video_info)
+from simba.misc_tools import (check_multi_animal_status,
+                              check_directionality_viable,
+                              SimbaTimer)
+from simba.drop_bp_cords import (getBpNames,
+                                 createColorListofList,
+                                 create_body_part_dictionary,
+                                 get_fn_ext)
 from simba.ROI_analyzer import ROIAnalyzer
 import pandas as pd
 import itertools
@@ -81,6 +91,8 @@ class ROIFeatureCreator(object):
             print('SIMBA ERROR: No data files found in {}'.format(self.out_dir))
             raise ValueError('SIMBA ERROR: No data files found in {}'.format(self.out_dir))
         print('Processing {} videos for ROI features...'.format(str(len(self.files_found))))
+        self.timer = SimbaTimer()
+        self.timer.start_timer()
 
     def analyze_ROI_data(self):
         """
@@ -178,8 +190,8 @@ class ROIFeatureCreator(object):
             save_path = os.path.join(self.out_dir, video_name + '.' + self.file_type)
             save_df(video_data.fillna(0), self.file_type, save_path)
             print('Created additional ROI features for {}...'.format(self.video_name))
-        print(
-            'SIMBA COMPLETE: Created additional ROI features for files within the project_folder/csv/features_extracted directory')
+        self.timer.stop_timer()
+        print('SIMBA COMPLETE: Created additional ROI features for files within the project_folder/csv/features_extracted directory (elapsed time: {}s)'.format(self.timer.elapsed_time_str))
 
 
 
