@@ -1,12 +1,19 @@
 __author__ = "Simon Nilsson", "JJ Choong"
 
-from simba.read_config_unit_tests import read_config_entry, read_config_file, check_file_exist_and_readable
-import os
-from simba.rw_dfs import read_df, save_df
-from simba.drop_bp_cords import get_fn_ext, drop_bp_cords
+from simba.read_config_unit_tests import (read_config_entry,
+                                          read_config_file,
+                                          check_file_exist_and_readable)
+
+from simba.rw_dfs import (read_df,
+                          save_df)
+from simba.train_model_functions import read_pickle
+from simba.drop_bp_cords import (get_fn_ext,
+                                 drop_bp_cords)
 from copy import deepcopy
 import pickle
 import warnings
+import time
+import os
 warnings.filterwarnings('ignore',category=FutureWarning)
 warnings.filterwarnings('ignore',category=DeprecationWarning)
 
@@ -38,7 +45,7 @@ class ValidateModelRunClf(object):
                  config_path: str,
                  input_file_path: str,
                  clf_path: str):
-
+        self.start_time = time.time()
         self.config = read_config_file(config_path)
         self.project_path = read_config_entry(self.config, 'General settings', 'project_path', data_type='folder_path')
         self.save_path = os.path.join(self.project_path, 'csv', 'validation')
@@ -51,7 +58,7 @@ class ValidateModelRunClf(object):
         data_df = read_df(input_file_path, self.file_type)
         output_df = deepcopy(data_df)
         data_df = drop_bp_cords(data_df, config_path)
-        clf = pickle.load(open(clf_path, 'rb'))
+        clf = read_pickle(file_path=clf_path)
         probability_col_name = 'Probability_{}'.format(classifier_name)
 
         try:
@@ -74,7 +81,9 @@ class ValidateModelRunClf(object):
 
         save_filename = os.path.join(self.save_path, file_name + '.' + self.file_type)
         save_df(output_df, self.file_type, save_filename)
-        print('Validation predictions generated for {} within the project_folder/csv/validation directory'.format(file_name))
+        elapsed_time = str(round(time.time() - self.start_time, 2))
+
+        print('SIMBA COMPLETE: Validation predictions generated for "{}" within the project_folder/csv/validation directory (elapsed time: {})'.format(file_name, elapsed_time))
         print('Click on "Generate plot" to inspect classifier probability thresholds. Then proceed to specify threshold and minimum bout length and click on "Validate".')
 #
 # ValidateModelRunClf(config_path=r"Z:\DeepLabCut\DLC_extract\Troubleshooting\DLC_two_mice\project_folder\project_config.ini",
