@@ -9,7 +9,9 @@ from shapely import geometry
 from shapely.geometry import Point, Polygon
 from simba.features_scripts.unit_tests import *
 from datetime import datetime
-from simba.misc_tools import get_fn_ext, detect_bouts
+from simba.misc_tools import (get_fn_ext,
+                              detect_bouts,
+                              SimbaTimer)
 from simba.read_config_unit_tests import read_config_file, read_config_entry, check_that_column_exist
 from simba.features_scripts.unit_tests import read_video_info_csv, read_video_info
 
@@ -51,14 +53,11 @@ class clf_within_ROI(object):
         self.rectangles_df = pd.read_hdf(self.ROIcoordinatesPath, key='rectangles')
         self.circles_df = pd.read_hdf(self.ROIcoordinatesPath, key='circleDf')
         self.polygon_df = pd.read_hdf(self.ROIcoordinatesPath, key='polygons')
-
         self.ROI_str_name_list = []
         for index, row in self.rectangles_df.iterrows(): self.ROI_str_name_list.append(row['Shape_type'] + ': ' + row['Name'])
-
         for index, row in self.circles_df.iterrows(): self.ROI_str_name_list.append(row['Shape_type'] + ': ' + row['Name'])
         for index, row in self.polygon_df.iterrows(): self.ROI_str_name_list.append(row['Shape_type'] + ': ' + row['Name'])
         self.ROI_str_name_list = list(set(self.ROI_str_name_list))
-
         self.behavior_names = []
         for i in range(model_nos):
             self.behavior_names.append(self.config.get('SML settings', 'target_name_' + str(i + 1)))
@@ -145,11 +144,12 @@ class clf_within_ROI(object):
         measurements: list
             Measurements to calculate aggregate statistics for. E.g., ['Total time by ROI (s)', 'Started bouts', 'Ended bouts']
         behavior_list: list
-            List of classifier names to calculate ROI statistics. E.g., ['Attack', 'Sniffing']
+            Classifier names to calculate ROI statistics. E.g., ['Attack', 'Sniffing']
         body_part_list: list
-            List of body-part names to use to infer animal location. Eg., ['Nose_1'].
+            Body-part names to use to infer animal location. Eg., ['Nose_1'].
         """
-
+        self.timer = SimbaTimer()
+        self.timer.start_timer()
         machine_results_path = os.path.join(self.projectPath, 'csv', 'machine_results')
         self.ROI_dict_lists, self.behavior_list, self.measurements = ROI_dict_lists, behavior_list, measurements
         self.file_type = read_config_entry(config=self.config, section='General settings', option='workflow_file_type', data_type='str')
@@ -238,7 +238,8 @@ class clf_within_ROI(object):
                         out_df.loc[len(out_df)] = [video_name, clf, roi_name, measurement_name, mesurement_value]
         out_path = os.path.join(self.log_path_dir, 'Classification_time_by_ROI_{}.csv'.format(self.date_time))
         out_df.to_csv(out_path)
-        print('SIMBA COMPLETE: Classification data by ROIs saved in {}'.format(out_path))
+        self.timer.stop_timer()
+        print('SIMBA COMPLETE: Classification data by ROIs saved in {} (selapsed time: {}s)'.format(out_path, self.timer.elapsed_time_str))
 
 # clf_ROI_analyzer = clf_within_ROI(config_ini="/Users/simon/Desktop/troubleshooting/train_model_project/project_folder/project_config.ini")
 # clf_ROI_analyzer.perform_ROI_clf_analysis(behavior_list=['Attack', 'Sniffing'], ROI_dict_lists={'Rectangle': ['rec'], 'Circle': ['Stimulus 1', 'Stimulus 2', 'Stimulus 3']}, body_part_list=['Nose_1'], measurements=['Total time by ROI (s)', 'Started bouts by ROI (count)', 'Ended bouts by ROI (count)'])
