@@ -4,7 +4,7 @@ from datetime import datetime
 import pandas as pd
 from simba.read_config_unit_tests import read_config_entry, check_file_exist_and_readable, read_config_file
 from simba.features_scripts.unit_tests import read_video_info_csv, read_video_info
-import os, glob
+import os, glob, time
 from simba.train_model_functions import get_all_clf_names
 from simba.drop_bp_cords import get_fn_ext
 from simba.misc_tools import detect_bouts
@@ -42,6 +42,7 @@ class ClfLogCreator(object):
                  data_measures: list,
                  classifiers: list):
 
+        self.start_time = time.time()
         self.chosen_measures = data_measures
         self.datetime = datetime.now().strftime('%Y%m%d%H%M%S')
         self.config, self.classifiers = read_config_file(config_path), classifiers
@@ -57,7 +58,7 @@ class ClfLogCreator(object):
         if len(self.files_found) == 0:
             print('SIMBA ERROR: No data files found in the project_folder/csv/machine_results directory. Run classifiers before analysing results.')
             raise ValueError('SIMBA ERROR: No data files found in the project_folder/csv/machine_results directory')
-        print('Analyzing {} files for {} classifiers...'.format(str(len(self.files_found)), str(len(self.clf_names))))
+        print('Analyzing {} file(s) for {} classifiers...'.format(str(len(self.files_found)), str(len(self.clf_names))))
 
     def analyze_data(self):
 
@@ -120,7 +121,8 @@ class ClfLogCreator(object):
         results_df = self.results_df[self.results_df['Measure'].isin(self.chosen_measures)].sort_values(by=['Video', 'Classifier', 'Measure']).reset_index(drop=True)
         results_df = results_df[results_df['Classifier'].isin(self.classifiers)].set_index('Video')
         results_df.to_csv(self.file_save_name)
-        print('SIMBA COMPLETE: Data log saved at {}'.format(self.file_save_name))
+        elapsed_time = str(round(time.time() - self.start_time, 4))
+        print('SIMBA COMPLETE: Data log saved at {} (elapsed time: {}s)'.format(self.file_save_name, elapsed_time))
 
 
 # test = ClfLogCreator(config_path=r"/Users/simon/Desktop/troubleshooting/train_model_project/project_folder/project_config.ini", data_measures=['Bout count', 'Total event duration','Mean event bout duration (s)', 'Median event bout duration (s)', 'First event occurrence', 'Mean event bout interval duration (s)',
