@@ -3,7 +3,7 @@ __author__ = "Simon Nilsson", "JJ Choong"
 import pandas as pd
 from joblib import Parallel, delayed
 from simba.read_config_unit_tests import read_config_entry, check_that_column_exist, read_config_file
-import os, glob
+import os, glob, time
 from simba.features_scripts.unit_tests import read_video_info_csv, read_video_info
 from simba.movement_processor import MovementProcessor
 from simba.misc_tools import check_multi_animal_status, get_fn_ext, get_video_meta_data, find_video_of_file, find_core_cnt
@@ -37,6 +37,7 @@ class DataPlotter(object):
                  config_path: str,
                  body_part: str=None):
 
+        self.start_time = time.time()
         self.config, self.config_path = read_config_file(config_path), config_path
         self.no_animals = read_config_entry(self.config, 'General settings', 'animal_no', 'int')
         self.project_path = read_config_entry(self.config, 'General settings', 'project_path', data_type='folder_path')
@@ -130,8 +131,8 @@ class DataPlotter(object):
 
             print('Data tables created for video {}...'.format(video_name))
             self.writer.release()
-
-        print('SIMBA COMPLETE: All data table videos created inside {}'.format(self.save_dir))
+        elapsed_time = str(round(time.time() - self.start_time, 4))
+        print('SIMBA COMPLETE: All data table videos created inside {} (elapsed time: {}s)'.format(self.save_dir, elapsed_time))
 
 
 # test = DataPlotter(config_path='/Users/simon/Desktop/troubleshooting/train_model_project/project_folder/project_config.ini')
