@@ -93,20 +93,26 @@ def copy_singlevideo_DPKini(inifile,source):
     except:
         pass
 
-def copy_singlevideo_ini(inifile, source):
-    print('Copying video...')
-    dest = str(os.path.dirname(inifile))
-    dir_name, filename, file_extension = get_fn_ext(source)
-    newFileName = os.path.join(filename + file_extension)
-    dest1 = os.path.join(dest, 'videos', newFileName)
-    if os.path.isfile(dest1):
-        print(os.path.basename(source), 'already exist in', dest1)
-    else:
-        shutil.copy(source, dest1)
-        nametoprint = os.path.join('', *(splitall(dest1)[-4:]))
-        print(os.path.basename(source),'copied to',nametoprint)
-    print('Finished copying video.')
+def copy_singlevideo_ini(simba_ini_path: str, source_path: str) -> None:
+    """ Helper to import single video file to SimBA project
+    Parameters
+    ----------
+    simba_ini_path: str
+        path to SimBA project config file in Configparser format
+    source_path: str
+        Path to video file.
+    """
 
+    print('Copying video file...')
+    dir_name, filename, file_extension = get_fn_ext(source_path)
+    new_filename = os.path.join(filename + file_extension)
+    destination = os.path.join(os.path.dirname(simba_ini_path), 'videos', new_filename)
+    if os.path.isfile(destination):
+        print('SIMBA ERROR: {} already exist in SimBA project. To import, delete this video file before importing the file.')
+        raise FileExistsError()
+    else:
+        shutil.copy(source_path, destination)
+        print('SIMBA COMPLETE: Video {} imported to SimBA project (project_folder/videos).'.format(filename))
 
 def copy_multivideo_DPKini(inifile,source,filetype):
     try:
