@@ -5,6 +5,7 @@ from simba.drop_bp_cords import *
 import numpy as np
 from simba.misc_tools import check_multi_animal_status
 
+
 class Interpolate(object):
 
     '''
@@ -15,7 +16,7 @@ class Interpolate(object):
     config_file_path: str
         path to SimBA project config file in Configparser format
     in_file: pd.DataFrame
-        Dataframe holding pose-estimation data
+        Pose-estimation data
 
     Notes
     -----
@@ -57,9 +58,6 @@ class Interpolate(object):
         Attribute: pd.Dataframe
             current_df
         """
-
-
-
         self.multi_index_headers = self.in_df.iloc[0:2]
         self.multi_index_headers_list = []
         for column in self.multi_index_headers:
@@ -84,7 +82,6 @@ class Interpolate(object):
             new_df
         """
 
-
         interpolation_type, interpolation_method = method_str.split(':')[0], method_str.split(':')[1].replace(" ", "").lower()
         self.animal_df_list, self.header_list_p = [], []
         if interpolation_type == 'Animal(s)':
