@@ -2,6 +2,8 @@ __author__ = "Simon Nilsson", "JJ Choong"
 
 import configparser
 
+import numpy as np
+
 from simba.drop_bp_cords import get_fn_ext, get_workflow_file_format
 from simba.rw_dfs import read_df, save_df
 import cv2
@@ -400,7 +402,7 @@ def smooth_data_savitzky_golay(config: configparser.ConfigParser,
         time_window_parameter = int(time_window_parameter)
     except:
         print(
-            'Savitzky-Golay smoothing failed for video {}. Time window parameter {} can not be interpreted as an integer.'.format(
+            'Savitzky-Golay smoothing failed for video {}. The specified time window parameter {} can not be interpreted as an integer.'.format(
                 str(os.path.basename(file_path)), str(time_window_parameter)))
     _, filename, _ = get_fn_ext(file_path)
     project_dir = config.get('General settings', 'project_path')
@@ -974,4 +976,17 @@ def get_color_dict():
             'Pink': (178, 102, 255),
             'Lime': (204, 255, 229),
             'Purple': (255, 51, 153),
-            'Cyan': (255, 255, 102)}
\ No newline at end of file
+            'Cyan': (255, 255, 102)}
+
+
+class SimbaTimer(object):
+    def start_timer(self):
+        self.timer = time.time()
+    def stop_timer(self):
+        if not hasattr(self, 'timer'):
+            self.elapsed_time = -1
+            self.elapsed_time_str = '-1'
+        else:
+            self.elapsed_time = round(time.time() - self.timer, 4)
+            self.elapsed_time_str = str(self.elapsed_time)
+
