@@ -1,7 +1,9 @@
 __author__ = "Simon Nilsson", "JJ Choong"
 
 import pandas as pd
-from simba.misc_tools import check_multi_animal_status, get_fn_ext
+from simba.misc_tools import (check_multi_animal_status,
+                              get_fn_ext,
+                              SimbaTimer)
 from datetime import datetime
 from simba.features_scripts.unit_tests import read_video_info_csv, read_video_info
 from simba.read_config_unit_tests import read_config_entry, check_that_column_exist, read_config_file
@@ -34,6 +36,8 @@ class MovementProcessor(object):
     def __init__(self,
                  config_path: str):
 
+        self.timer = SimbaTimer()
+        self.timer.start_timer()
         self.timestamp = datetime.now().strftime('%Y%m%d%H%M%S')
         self.config = read_config_file(config_path)
         self.project_path = read_config_entry(self.config, 'General settings', 'project_path', data_type='folder_path')
@@ -42,8 +46,12 @@ class MovementProcessor(object):
         self.in_dir = os.path.join(self.project_path, 'csv', 'outlier_corrected_movement_location')
         self.vid_info_df = read_video_info_csv(os.path.join(self.logs_path, 'video_info.csv'))
         self.file_type = read_config_entry(self.config, 'General settings', 'workflow_file_type', 'str', 'csv')
-        self.animal_cnt = read_config_entry(self.config, 'process movements', 'no_of_animals', 'int')
-        self.p_threshold = read_config_entry(self.config, 'process movements', 'probability_threshold', 'float')
+        try:
+            self.animal_cnt = read_config_entry(self.config, 'process movements', 'no_of_animals', 'int')
+            self.p_threshold = read_config_entry(self.config, 'process movements', 'probability_threshold', 'float')
+        except:
+            print('Please analyze movements before visualizing data.')
+            raise ValueError('Please analyze movements before visualizing data.')
         self.multiAnimalStatus, self.multiAnimalIDList = check_multi_animal_status(self.config, self.animal_cnt)
         self.bp_dict = defaultdict(list)
         self.bp_columns = []
@@ -72,7 +80,7 @@ class MovementProcessor(object):
         Returns
         ----------
         Attribute: dict
-            self.results
+            results
 
         """
         self.results = {}
@@ -118,7 +126,8 @@ class MovementProcessor(object):
                 for measure, mesure_val in animal_data.items():
                     self.out_df.loc[len(self.out_df)] = [video, animal, measure, mesure_val]
         self.out_df.set_index('Video').to_csv(self.save_path)
-        print('SIMBA COMPLETE: Movement log saved in {}'.format(self.save_path))
+        self.timer.stop_timer()
+        print('SIMBA COMPLETE: Movement log saved in {} (elapsed time: {}s)'.format(self.save_path, self.timer.elapsed_time_str))
 
 #
 # test = MovementProcessor(config_path='/Users/simon/Desktop/troubleshooting/train_model_project/project_folder/project_config.ini')
