@@ -280,7 +280,7 @@ class FSTTCPopUp(object):
         fsttc_settings_frm = LabelFrame(fsttc_main,text='FSTTC Settings', pady=5, padx=5,font=("Helvetica",12,'bold'),fg='black')
         graph_cb_var = BooleanVar()
         graph_cb = Checkbutton(fsttc_settings_frm,text='Create graph',variable=graph_cb_var)
-        time_delta = Entry_Box(fsttc_settings_frm,'Time Delta','10')
+        time_delta = Entry_Box(fsttc_settings_frm,'Time Delta','10', validation='numeric')
         behaviors_frm = LabelFrame(fsttc_settings_frm,text="Behaviors")
         clf_var_dict, clf_cb_dict = {}, {}
         for clf_cnt, clf in enumerate(self.clf_names):
@@ -1169,7 +1169,7 @@ class VisualizePoseInFolderPopUp(object):
             self.confirm_btn = Button(self.adv_settings_frm, text='Confirm', command=lambda: self.launch_clr_menu())
             self.specify_animals_dropdown = DropDownMenu(self.adv_settings_frm, 'ANIMAL COUNT: ', list(range(1, 11)), '20')
             self.adv_settings_frm.grid(row=5, column=0, pady=10)
-            self.specify_animals_dropdown.grid(row=0, column=0)
+            self.specify_animals_dropdown.grid(row=0, column=0, sticky=NW)
             self.confirm_btn.grid(row=0, column=1)
         elif self.advanced_settings_btn['text'] == 'CLOSE ADVANCED SETTINGS':
             if hasattr(self, 'adv_settings_frm'):
