@@ -1,7 +1,11 @@
 __author__ = "Simon Nilsson", "JJ Choong"
 
-from simba.read_config_unit_tests import read_config_entry, check_that_column_exist, read_config_file
-from simba.features_scripts.unit_tests import read_video_info_csv, read_video_info
+from simba.read_config_unit_tests import (read_config_entry,
+                                          check_that_column_exist,
+                                          read_config_file)
+from simba.features_scripts.unit_tests import (read_video_info_csv,
+                                               read_video_info)
+from simba.misc_tools import SimbaTimer
 import os, glob
 from simba.drop_bp_cords import get_fn_ext
 from simba.rw_dfs import read_df
@@ -46,6 +50,9 @@ class TresholdPlotCreatorSingleProcess(object):
         self.file_type = read_config_entry(self.config, 'General settings', 'workflow_file_type', 'str', 'csv')
         self.data_in_dir = os.path.join(self.project_path, 'csv', 'machine_results')
         self.files_found = glob.glob(self.data_in_dir + '/*.' + self.file_type)
+        if len(self.files_found) == 0:
+            print('SIMBA ERROR: Zero files found in the project_folder/csv/machine_results directory. Create classification results before visualizing classification probability charts')
+            raise FileNotFoundError('SIMBA ERROR: Zero files found in the project_folder/csv/machine_results directory. Create classification results before visualizing classification probability charts')
         self.vid_info_df = read_video_info_csv(os.path.join(self.project_path, 'logs', 'video_info.csv'))
         self.out_parent_dir = os.path.join(self.project_path, 'frames', 'output', 'probability_plots')
         self.orginal_clf_name = clf_name
@@ -55,6 +62,8 @@ class TresholdPlotCreatorSingleProcess(object):
         self.fourcc = cv2.VideoWriter_fourcc(*'mp4v')
         if not os.path.exists(self.out_parent_dir): os.makedirs(self.out_parent_dir)
         print('Processing {} video(s)...'.format(str(len(self.files_found))))
+        self.timer = SimbaTimer()
+        self.timer.start_timer()
 
 
     def create_plot(self):
@@ -110,12 +119,11 @@ class TresholdPlotCreatorSingleProcess(object):
                 if self.video_setting:
                     self.writer.write(frame)
                 print('Probability frame: {} / {}. Video: {} ({}/{})'.format(str(index+1), str(len(data_df)), self.video_name, str(file_cnt + 1), len(self.files_found)))
-
             if self.video_setting:
                 self.writer.release()
             print('Probability plot for video {} saved...'.format(self.video_name))
-
-        print('SIMBA COMPLETE: All probability visualizations created in project_folder/frames/output/probability_plots directory')
+        self.timer.stop_timer()
+        print('SIMBA COMPLETE: All probability visualizations created in project_folder/frames/output/probability_plots directory (elapsed time: {}s)'.format(self.timer.elapsed_time_str))
 
 # test = TresholdPlotCreatorSingleProcess(config_path='/Users/simon/Desktop/troubleshooting/train_model_project/project_folder/project_config.ini', frame_setting=False, video_setting=True, clf_name='Attack')
 # test.create_plot()
