@@ -7,14 +7,15 @@ from simba.read_config_unit_tests import (read_config_entry,
 from simba.features_scripts.unit_tests import (read_video_info_csv,
                                                read_video_info)
 import functools
-from simba.misc_tools import find_core_cnt, remove_a_folder
+from simba.misc_tools import (find_core_cnt,
+                              remove_a_folder,
+                              SimbaTimer)
 import os, glob
 from simba.drop_bp_cords import get_fn_ext
 from simba.rw_dfs import read_df
 import matplotlib.pyplot as plt
 import cv2
 import numpy as np
-from copy import deepcopy
 import shutil
 import multiprocessing
 import platform
@@ -116,6 +117,9 @@ class TresholdPlotCreatorMultiprocess(object):
         self.file_type = read_config_entry(self.config, 'General settings', 'workflow_file_type', 'str', 'csv')
         self.data_in_dir = os.path.join(self.project_path, 'csv', 'machine_results')
         self.files_found = glob.glob(self.data_in_dir + '/*.' + self.file_type)
+        if len(self.files_found) == 0:
+            print('SIMBA ERROR: Zero files found in the project_folder/csv/machine_results directory. Create classification results before visualizing classification probability charts')
+            raise FileNotFoundError('SIMBA ERROR: Zero files found in the project_folder/csv/machine_results directory. Create classification results before visualizing classification probability charts')
         self.vid_info_df = read_video_info_csv(os.path.join(self.project_path, 'logs', 'video_info.csv'))
         self.out_parent_dir = os.path.join(self.project_path, 'frames', 'output', 'probability_plots')
         self.clf_name = clf_name
@@ -128,6 +132,8 @@ class TresholdPlotCreatorMultiprocess(object):
         self.chunksize = 1
         if not os.path.exists(self.out_parent_dir): os.makedirs(self.out_parent_dir)
         print('Processing {} video(s)...'.format(str(len(self.files_found))))
+        self.timer = SimbaTimer()
+        self.timer.start_timer()
 
     def create_plot(self):
         start_time = time.time()
@@ -197,8 +203,8 @@ class TresholdPlotCreatorMultiprocess(object):
                         break
             print('Video {} complete...'.format(self.video_name))
 
-        elapsed_time = str(round(time.time() - start_time, 2)) + 's'
-        print('SIMBA COMPLETE: All probability visualizations created in project_folder/frames/output/probability_plots directory. Elapsed time {}'.format(elapsed_time))
+        self.timer.stop_timer()
+        print('SIMBA COMPLETE: All probability visualizations created in project_folder/frames/output/probability_plots directory (elapsed time: {}s)'.format(self.timer.elapsed_time_str))
 
 # if __name__== "__main__":
 #     test = TresholdPlotCreator(config_path='/Users/simon/Desktop/troubleshooting/train_model_project/project_folder/project_config.ini',
