@@ -1,10 +1,16 @@
 __author__ = "Simon Nilsson", "JJ Choong"
 
-from configparser import ConfigParser, MissingSectionHeaderError
-from simba.features_scripts.unit_tests import read_video_info_csv, read_video_info
-from simba.read_config_unit_tests import (check_int, check_str, check_float, read_config_entry, read_config_file)
+from simba.features_scripts.unit_tests import (read_video_info_csv,
+                                               read_video_info)
+from simba.read_config_unit_tests import (check_int,
+                                          check_str,
+                                          check_float,
+                                          read_config_entry,
+                                          read_config_file)
 from simba.train_model_functions import get_model_info
-from simba.misc_tools import get_fn_ext, plug_holes_shortest_bout
+from simba.misc_tools import (get_fn_ext,
+                              plug_holes_shortest_bout,
+                              SimbaTimer)
 from simba.drop_bp_cords import drop_bp_cords
 from simba.rw_dfs import read_df, save_df
 import os, glob
@@ -51,8 +57,12 @@ class RunModel(object):
         self.vid_info_df = read_video_info_csv(os.path.join(self.project_path, 'logs', 'video_info.csv'))
         self.model_dict = get_model_info(self.config, self.model_cnt)
         self.files_found = glob.glob(self.files_in_dir + '/*.' + self.file_type)
+        if len(self.files_found) == 0:
+            print('SIMBA ERROR: Zero files found in the project_folder/csv/features_extracted directory. Create features before running classifier.')
+            raise FileNotFoundError('SIMBA ERROR: Zero files found in the project_folder/csv/features_extracted directory. Create features before running classifier.')
         print('Analyzing {} file(s) with {} classifier(s)'.format(str(len(self.files_found)), str(len(self.model_dict))))
-
+        self.timer = SimbaTimer()
+        self.timer.start_timer()
 
     def run_models(self):
         for file_cnt, file_path in enumerate(self.files_found):
@@ -81,7 +91,8 @@ class RunModel(object):
                 out_df = plug_holes_shortest_bout(data_df=out_df, clf_name=m_hyp['model_name'], fps=fps, shortest_bout=m_hyp['minimum_bout_length'])
             save_df(out_df, self.file_type, file_save_path)
             print('Predictions created for {} ...'.format(file_name))
-        print('SIMBA COMPLETE: Machine predictions complete. Files saved in project_folder/csv/machine_results directory')
+        self.timer.stop_timer()
+        print('SIMBA COMPLETE: Machine predictions complete. Files saved in project_folder/csv/machine_results directory (elapsed time: {}s)'.format(self.timer.elapsed_time_str))
 
 # test = RunModel(config_path='/Users/simon/Desktop/train_model_project/project_folder/project_config.ini')
 # test.run_models()
