@@ -33,7 +33,7 @@ class SleapCsvImporter(object):
     data_folder: str
         Path to folder containing SLEAP data in `.slp` format.
     actor_IDs: list
-        List of animal names.
+         Animal names.
     interpolation_settings: str
         String defining the pose-estimation interpolation method. OPTIONS: 'None', 'Animal(s): Nearest',
         'Animal(s): Linear', 'Animal(s): Quadratic','Body-parts: Nearest', 'Body-parts: Linear',
@@ -71,18 +71,22 @@ class SleapCsvImporter(object):
         multi_animal_status, multi_animal_id_lst = check_multi_animal_status(self.config, self.animal_cnt)
         self.x_cols, self.y_cols, self.p_cols = getBpNames(self.config_path)
         color_lst = createColorListofList(self.animal_cnt, len(self.x_cols))
-        self.animal_bp_dict = create_body_part_dictionary(multi_animal_status, self.actor_ids, self.animal_cnt, self.x_cols, self.y_cols, self.p_cols, color_lst)
         self.video_dir = os.path.join(self.project_path, 'videos')
         self.files_found = glob.glob(data_folder + '/*.csv')
         if len(self.files_found) == 0:
-            print('SIMBA ERROR: No CSV files found in the {} directory'.format(str(len(self.files_found))))
+            print('SIMBA ERROR: Zero CSV files found in the data directory ({})'.format(data_folder))
             raise ValueError('SIMBA ERROR: No CSV files found in input directory')
         self.save_folder = os.path.join(self.project_path, 'csv', 'input_csv')
         self.space_scaler, self.radius_scaler, self.res_scaler, self.font_scaler, self.add_spacer, self.frame_no = 40, 10, 1500, 1.2, 2, 1
         self.bp_names_csv_path = os.path.join(self.project_path, 'logs', 'measures', 'pose_configs', 'bp_names', 'project_bp_names.csv')
         self.pose_settings = self.config.get('create ensemble settings', 'pose_estimation_body_parts')
         if (self.pose_settings is 'user_defined'): self.__update_config_animal_cnt()
-        if (self.animal_cnt > 1): self.__update_bp_headers_file()
+        self.animal_bp_dict = create_body_part_dictionary(multi_animal_status, self.actor_ids, self.animal_cnt, self.x_cols, self.y_cols, self.p_cols, color_lst)
+        if self.animal_cnt > 1:
+            self.__update_bp_headers_file()
+            multi_animal_status, multi_animal_id_lst = check_multi_animal_status(self.config, self.animal_cnt)
+            self.x_cols, self.y_cols, self.p_cols = getBpNames(self.config_path)
+            self.animal_bp_dict = create_body_part_dictionary(multi_animal_status, self.actor_ids, self.animal_cnt, self.x_cols, self.y_cols, self.p_cols, color_lst)
         self.df_headers = getBpHeaders(inifile=self.config_path)
 
     def __update_config_animal_cnt(self):
@@ -272,7 +276,7 @@ class SleapCsvImporter(object):
             self.out_df.to_csv(self.save_path)
 
     def __run_interpolation(self):
-        print('Interpolating missing values in video {} (Method: {} ...'.format(self.video_basename, self.interpolation_settings))
+        print('Interpolating missing values in video {} (Method: {}) ...'.format(self.video_basename, self.interpolation_settings))
         if self.file_type == 'parquet':
             data_df = pd.read_parquet(self.save_path)
         if self.file_type == 'csv':
@@ -289,7 +293,7 @@ class SleapCsvImporter(object):
 
     def __run_smoothing(self):
         if self.smoothing_settings['Method'] == 'Gaussian':
-            print('Performing Gaussian smoothing on video {}...'.format(self.video_basename))
+            print('Performing Gaussian smoothing on video "{}" ...'.format(self.video_basename))
             time_window = self.smoothing_settings['Parameters']['Time_window']
             smooth_data_gaussian(config=self.config, file_path=self.save_path, time_window_parameter=time_window)
 
@@ -300,7 +304,7 @@ class SleapCsvImporter(object):
 
     @staticmethod
     @jit(nopython=True)
-    def __transpose_table(data: np.array, idx: np.array, animal_cnt: int):
+    def __transpose_multi_animal_data_table(data: np.array, idx: np.array, animal_cnt: int) -> np.array:
         results = np.full((np.max(idx[:, 1]), data.shape[1]*animal_cnt), 0.0)
         for i in prange(np.max(idx[:, 1])):
             for j in prange(animal_cnt):
@@ -321,10 +325,21 @@ class SleapCsvImporter(object):
             idx = data_df.iloc[:, :2]
             idx['track'] = idx['track'].str.replace(r'[^\d.]+', '').astype(int)
             data_df = data_df.iloc[:, 2:]
-            self.data_df = pd.DataFrame(self.__transpose_table(data=data_df.values, idx=idx.values, animal_cnt=self.animal_cnt))
-            p_df = pd.DataFrame(1.0, index=self.data_df.index, columns=self.data_df.columns[1::2] + .5)
-            self.data_df = pd.concat([self.data_df, p_df], axis=1).sort_index(axis=1)
-            self.data_df.columns = self.df_headers
+            if self.animal_cnt > 1:
+                self.data_df = pd.DataFrame(self.__transpose_multi_animal_data_table(data=data_df.values, idx=idx.values, animal_cnt=self.animal_cnt))
+                p_df = pd.DataFrame(1.0, index=self.data_df.index, columns=self.data_df.columns[1::2] + .5)
+                self.data_df = pd.concat([self.data_df, p_df], axis=1).sort_index(axis=1)
+                self.data_df.columns = self.df_headers
+            else:
+                idx = list(idx.drop('track', axis=1)['frame_idx'])
+                self.data_df = data_df.set_index([idx]).sort_index()
+                self.data_df.columns = np.arange(len(self.data_df.columns))
+                self.data_df = self.data_df.reindex(range(self.data_df.index[0], self.data_df.index[-1] + 1), fill_value=0)
+                p_df = pd.DataFrame(1.0, index=self.data_df.index, columns=self.data_df.columns[1::2] + .5)
+                self.data_df = pd.concat([self.data_df, p_df], axis=1).sort_index(axis=1)
+                self.data_df.columns = self.df_headers
+                self.out_df = deepcopy(self.data_df)
+
             if self.animal_cnt > 1:
                 self.video_path = find_video_of_file(video_dir=self.video_dir, filename=self.video_basename)
                 self.video_info = get_video_meta_data(self.video_path)
@@ -343,10 +358,20 @@ class SleapCsvImporter(object):
                 self.__run_interpolation()
             if self.smoothing_settings['Method'] != 'None':
                 self.__run_smoothing()
+            print('Video "{}" imported...'.format(self.video_basename))
+        print('SIMBA COMPLETE: {} file(s) imported to the SimBA project (project_folder/csv/input_csv directory)'.format(str(len(self.files_found))))
+
+
+# test = SleapCsvImporter(config_path=r'/Users/simon/Desktop/envs/troubleshooting/Hornet/project_folder/project_config.ini',
+#                  data_folder=r'/Users/simon/Desktop/envs/troubleshooting/Hornet_single_slp/import',
+#                  actor_IDs=['Hornet'],
+#                  interpolation_settings="Body-parts: Nearest",
+#                  smoothing_settings = {'Method': 'Savitzky Golay', 'Parameters': {'Time_window': '200'}})
+# test.initate_import_slp()
 
 
 # test = SleapCsvImporter(config_path=r'/Users/simon/Desktop/envs/troubleshooting/slp_1_animal_1_bp/project_folder/project_config.ini',
-#                  data_folder=r'/Users/simon/Desktop/envs/troubleshooting/slp_1_animal_1_bp/import/temp',
+#                  data_folder=r'/Users/simon/Desktop/envs/troubleshooting/slp_1_animal_1_bp/import',
 #                  actor_IDs=['Termite_1', 'Termite_2', 'Termite_3', 'Termite_4', 'Termite_5'],
 #                  interpolation_settings="Body-parts: Nearest",
 #                  smoothing_settings = {'Method': 'Savitzky Golay', 'Parameters': {'Time_window': '200'}})
