@@ -79,6 +79,9 @@ class ImportSLEAP(object):
         self.project_path = self.config.get('General settings', 'project_path')
         self.video_folder = os.path.join(self.project_path, 'videos')
         self.files_found = glob.glob(data_folder + '/*.slp')
+        if len(self.files_found) == 0:
+            print('SIMBA ERROR: Zero .slp files found in {} directory'.format(data_folder))
+            raise ValueError()
         self.save_folder = os.path.join(self.project_path, 'csv', 'input_csv')
         self.file_format = get_workflow_file_format(self.config)
         self.animals_no = len(self.actors_IDs)
@@ -97,6 +100,7 @@ class ImportSLEAP(object):
         color_lst = createColorListofList(self.animals_no, len(self.analysis_dict['ordered_bps']))
         self.animal_bp_dict = create_body_part_dictionary(multi_animal_status, multi_animal_id_lst, self.animals_no,
                                                           Xcols, Ycols, [], color_lst)
+
         for file_path in self.save_paths_lst:
             self.data_df = read_df(file_path, self.file_format)
             self.data_df.columns = getBpHeaders(self.ini_path)
