@@ -1,7 +1,6 @@
 __author__ = "Simon Nilsson", "JJ Choong"
 
 import os
-from simba.drop_bp_cords import drop_bp_cords
 import numpy as np
 import pandas as pd
 from simba.rw_dfs import read_df
@@ -13,7 +12,6 @@ from sklearn.model_selection import learning_curve
 from sklearn.model_selection import ShuffleSplit
 from sklearn.metrics import precision_recall_curve
 from sklearn.ensemble import RandomForestClassifier
-import sklearn
 from copy import deepcopy
 from sklearn.tree import export_graphviz
 from subprocess import call
@@ -21,7 +19,8 @@ from yellowbrick.classifier import ClassificationReport
 import shap
 from simba.drop_bp_cords import GenerateMetaDataFileHeaders
 from tabulate import tabulate
-from simba.shap_calcs import shap_summary_calculations
+#from simba.shap_calcs import shap_summary_calculations
+from simba.shap_agg_stats_visualizer import ShapAggregateStatisticsVisualizer
 from simba.read_config_unit_tests import (check_int, check_str, check_float, read_config_entry, check_file_exist_and_readable)
 import configparser
 import platform
@@ -29,6 +28,7 @@ from sklearn.utils import parallel_backend
 import pickle
 from dtreeviz.trees import tree, dtreeviz
 import matplotlib.pyplot as plt
+import time
 plt.switch_backend('agg')
 
 def read_all_files_in_folder(file_paths: list,
@@ -55,6 +55,7 @@ def read_all_files_in_folder(file_paths: list,
 
     """
 
+    start = time.time()
     df_concat = pd.DataFrame()
     for file in file_paths:
         _, vid_name, _ = get_fn_ext(file)
@@ -75,7 +76,8 @@ def read_all_files_in_folder(file_paths: list,
     if len(df_concat) == 0:
         raise ValueError('ANNOTATION ERROR: SimBA found 0 annotated frames in the project_folder/csv/targets_inserted directory')
     df_concat = df_concat.loc[:, ~df_concat.columns.str.contains('^Unnamed')]
-
+    elapsed_time = str(round(time.time() - start, 2))
+    print('{} file(s) read in {}s ...'.format(str(len(file_paths)), elapsed_time))
     return df_concat.reset_index(drop=True)
 
 
@@ -605,7 +607,7 @@ def create_shap_log(ini_file_path: str,
     y_df: pd.DataFrame
         Pandas dataframe holding test target.
     x_names: list
-        List of feature names.
+        Feature names.
     clf_name:
         Classifier name.
     cnt_present: int
@@ -657,8 +659,11 @@ def create_shap_log(ini_file_path: str,
     else:
         out_df_shap.to_csv(os.path.join(save_path, 'SHAP_values_' + '_' + str(save_file_no) + clf_name + '.csv'))
         out_df_raw.to_csv(os.path.join(save_path, 'RAW_SHAP_feature_values_' + '_' + str(save_file_no) + clf_name + '.csv'))
-    shap_summary_calculations(ini_file_path, out_df_shap, clf_name, expected_value, save_path)
-
+    _ = ShapAggregateStatisticsVisualizer(config_path=ini_file_path,
+                                          classifier_name=clf_name,
+                                          shap_df=out_df_shap,
+                                          shap_baseline_value=expected_value,
+                                          save_path=save_path)
 
 def print_machine_model_information(model_dict: dict):
     """
@@ -861,6 +866,14 @@ def insert_column_headers_for_outlier_correction(data_df: pd.DataFrame,
         return data_df
 
 
+def read_pickle(file_path: str) -> object:
+    try:
+        clf = pickle.load(open(file_path, 'rb'))
+    except pickle.UnpicklingError:
+        print('SIMBA ERROR: Can not read {} as a classifier file (pickle).'.format(os.path.basename(file_path)))
+        raise pickle.UnpicklingError('SIMBA ERROR: Can not read user-specified classifier file as pickled file.')
+    return clf
+
 # df = pd.read_csv('/Users/simon/Desktop/troubleshooting/train_model_project/project_folder/csv/targets_inserted/Together_1.csv', index_col=0)
 # df = df.drop('Sniffing', axis=1)
 # df = drop_bp_cords(df=df, config_path='/Users/simon/Desktop/troubleshooting/train_model_project/project_folder/project_config.ini')
