@@ -83,8 +83,8 @@ class TrainSingleModel(object):
         self.class_names = ['Not_' + self.clf_name, self.clf_name]
         self.x_df, self.y_df = split_df_to_x_y(self.x_y_df, self.clf_name)
         self.feature_names = self.x_df.columns
-        print('# of features in dataset: ' + str(len(self.x_df.columns)))
-        print('# of {} frames in dataset: {}'.format(self.clf_name, str(self.y_df.sum())))
+        print('Number of features in dataset: ' + str(len(self.x_df.columns)))
+        print('Number of {} frames in dataset: {} ({}%)'.format(self.clf_name, str(self.y_df.sum()), str(round(self.y_df.sum() / len(self.y_df), 4) * 100)))
 
     def perform_sampling(self):
         """
